#!/bin/bash

# 不使用 MG 寄信 獨立IP網域列表，檔案不存在則建立
if [ ! -e /etc/excludesenderdomains ]; then
    touch /etc/excludesenderdomains
fi

# 不使用 MG 寄信 排外網域列表，檔案不存在則建立
if [ ! -e /etc/excludeotherdomains ]; then
    touch /etc/excludeotherdomains
fi

# 檢查是否有輸入參數
if [ -z "$1" ]; then
    echo ''
    echo '使用說明：'
    echo "/opt/cpinst/jacky_script/auto_update_excludesenderdomains.sh --run [ 將 獨立IP網域列表、排外網域列表 更新至 /etc/excludesenderdomains ]"
    echo ''
    exit 1
fi

if [ "$1" == "--run" ]; then

    # 確認手動增加不使用 MG 寄信網域是否有差異
    ######################

    # 如果 /mnt/old_excludeotherdomains 檔案不存在則建立
    old_other='/mnt/old_excludeotherdomains'
    if [ ! -f "$old_other" ]; then
        touch "$old_other"
    fi

    new_other='/etc/excludeotherdomains'

    # 比對 /mnt/old_excludeotherdomains 與 /etc/excludeotherdomains 是否有所差異
    if diff "$old_other" "$new_other" > /dev/null; then
        #echo "不使用 MG 寄信網域列表 沒有差異"
        add_check='not_update'
    else
        #echo "不使用 MG 寄信網域列表 有差異"
        cp -f "$new_other" "$old_other"
        add_check='need_update'
    fi

    ######################

    # 確認 獨立IP 寄信網域列表是否有差異
    ######################

    # 如果 /mnt/old_excludesenderdomains.txt 檔案不存在則建立
    old_list='/mnt/old_excludesenderdomains.txt'
    if [ ! -f "$old_list" ]; then
        touch "$old_list"
    fi

    # 將目前 /etc/mailips 使用獨立IP網域列表輸出至 /mnt/new_excludesenderdomains.txt 檔案
    new_list='/mnt/new_excludesenderdomains.txt'
    mapfile -t domain_list < <(cat /etc/mailips | grep -v ^* | awk -F\: '{print $1}')
    printf "%s\n" "${domain_list[@]}" > "$new_list"

    # 比對 /mnt/old_excludesenderdomains.txt 與 /mnt/new_excludesenderdomains.txt 是否有所差異
    if diff "$old_list" "$new_list" > /dev/null; then
        #echo "獨立IP網域列表 沒有差異"
        domain_check='not_update'
    else
        #echo "獨立IP網域列表 有差異"
        cp -f "$new_list" "$old_list"
        domain_check='need_update'
    fi

    ######################

    # 如果 不使用 MG 寄信 排外網域列表 與 獨立IP寄信網域列表 有差異，才會更新 /etc/excludesenderdomains
    if [ "${add_check}" == 'need_update' ] || [ "${domain_check}" == 'need_update' ]; then

        #echo '需要更新 /etc/excludesenderdomains'

        rm -f /etc/excludesenderdomains ; touch /etc/excludesenderdomains

        for element1 in `cat /etc/excludeotherdomains`; do
            echo "$element1" >> /etc/excludesenderdomains
        done

        for element2 in "${domain_list[@]}"; do
            echo "$element2" >> /etc/excludesenderdomains
        done

        exit

    elif [ "${add_check}" == 'not_update' ] && [ "${domain_check}" == 'not_update' ]; then

        #echo '不需要更新'
        exit 0

    fi

fi
